
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.17.6.post1',
    'branch_nick': '(HEAD',
    'revision_id': 'f8e87bf5917f64f31081ca123b79995efaf5bae2',
    'revno': 6897
}
